@@ -21,6 +21,17 @@ class Auth:
     def token(self) -> Optional[str]:
         return os.getenv("AUTH_TOKEN", None)
 
+    def can_authenticate(self) -> bool:
+        auth_options = self.token or (self.username and self.password)
+        return auth_options is not None
+
+    def __eq__(self, other):
+        return (
+            self.token == other.toker and
+            self.username == self.username and
+            self.password == self.password
+        )
+
 
 @configuration(yaml_file=config_file, prefix="")
 class AppConfig:
