@@ -7,4 +7,5 @@ def no_transform(data: dict):
 
 
 def to_pandas_with_index(data: dict, index: str = 'date') -> DataFrame:
-    return pd.DataFrame(data).set_index(index, drop=False)
+    # necessary to drop column in order to avoid duplicates when converting to json
+    return pd.DataFrame(data).set_index(index, drop=True)
