@@ -1,7 +1,7 @@
 from dataclasses import asdict
 
 from algoralabs.common.enum import PermissionRequest
-from algoralabs.common.requests import __get_request, __put_request
+from algoralabs.common.requests import __get_request, __put_request, __delete_request
 from algoralabs.decorators.data import data_request
 
 
@@ -20,6 +20,11 @@ def get_resource(id: str):
     return __get_request(endpoint)
 
 
+def delete_resource(id: str):
+    endpoint = f"research-service/resource/{id}"
+    return __delete_request(endpoint)
+
+
 @data_request(transformer=lambda data: data)
 def create_permission(request: PermissionRequest):
     endpoint = f"research-service/permission"
